@@ -494,9 +494,9 @@ class ConanAPIV1(object):
         self._client_cache.invalidate()
 
     @api_method
-    def config_install(self, item, verify_ssl, config_type=None):
+    def config_install(self, item, verify_ssl, config_type=None, args=None):
         from conans.client.conf.config_installer import configuration_install
-        return configuration_install(item, self._client_cache, self._user_io.out, verify_ssl, config_type)
+        return configuration_install(item, self._client_cache, self._user_io.out, verify_ssl, config_type, args)
 
     def _info_get_profile(self, reference, install_folder, profile_name, settings, options, env):
         cwd = get_cwd()
