@@ -1,11 +1,14 @@
-from conans.errors import RequestErrorException, NotFoundException, ForbiddenException
-from conans.server.store.file_manager import FileManager
+import re
+from fnmatch import translate
+
+from conans.errors import RequestErrorException, NotFoundException, ForbiddenException, \
+    ConanException
 import os
 import jwt
-from conans.util.files import mkdir
-from conans.model.ref import PackageReference
+from conans.util.files import mkdir, list_folder_subdirs
+from conans.model.ref import PackageReference, ConanFileReference
 from conans.util.log import logger
-from conans.search.search import search_packages, search_recipes
+from conans.search.search import search_packages, _partial_match
 
 
 class FileUploadDownloadService(object):
@@ -64,22 +67,66 @@ class FileUploadDownloadService(object):
 
 class SearchService(object):
 
-    def __init__(self, authorizer, paths, auth_user):
+    def __init__(self, authorizer, server_store, auth_user):
         self._authorizer = authorizer
-        self._paths = paths
+        self._server_store = server_store
         self._auth_user = auth_user
 
     def search_packages(self, reference, query):
         self._authorizer.check_read_conan(self._auth_user, reference)
-        info = search_packages(self._paths, reference, query)
+        info = search_packages(self._server_store, reference, query)
         return info
 
+    def search_recipes(self, pattern=None, ignorecase=True):
+
+        def get_ref(_pattern):
+            if not isinstance(_pattern, ConanFileReference):
+                try:
+                    r = ConanFileReference.loads(_pattern)
+                except (ConanException, TypeError):
+                    r = None
+            else:
+                r = _pattern
+            return r
+
+        def get_folders_levels(_pattern):
+            """If a reference with revisions is detected compare with 5 levels of subdirs"""
+            r = get_ref(_pattern)
+            return 5 if r and r.revision else 4
+
+        # Check directly if it is a reference
+        ref = get_ref(pattern)
+        if ref:
+            # Avoid resolve latest revision if a version range is passed or we are performing a
+            # package remove (all revisions)
+            path = self._server_store.conan(ref, resolve_latest=False)
+            if self._server_store.path_exists(path):
+                return [ref]
+
+        # Conan references in main storage
+        if pattern:
+            pattern = str(pattern)
+            b_pattern = translate(pattern)
+            b_pattern = re.compile(b_pattern, re.IGNORECASE) if ignorecase else re.compile(b_pattern)
+
+        subdirs = list_folder_subdirs(basedir=self._server_store.store, level=get_folders_levels(pattern))
+        if not pattern:
+            return sorted([ConanFileReference(*folder.split("/")) for folder in subdirs])
+        else:
+            ret = []
+            for subdir in subdirs:
+                conan_ref = ConanFileReference(*subdir.split("/"))
+                if _partial_match(b_pattern, conan_ref):
+                    ret.append(conan_ref)
+
+            return sorted(ret)
+
     def search(self, pattern=None, ignorecase=True):
         """ Get all the info about any package
             Attributes:
                 pattern = wildcards like opencv/*
         """
-        references = search_recipes(self._paths, pattern, ignorecase)
+        references = self.search_recipes(pattern, ignorecase)
         filtered = []
         # Filter out restricted items
         for conan_ref in references:
@@ -94,11 +141,10 @@ class SearchService(object):
 class ConanService(object):
     """Handles authorization and expose methods for REST API"""
 
-    def __init__(self, authorizer, file_manager, auth_user):
-        assert(isinstance(file_manager, FileManager))
+    def __init__(self, authorizer, server_store, auth_user):
 
         self._authorizer = authorizer
-        self._file_manager = file_manager
+        self._server_store = server_store
         self._auth_user = auth_user
 
     def get_conanfile_snapshot(self, reference):
@@ -106,7 +152,7 @@ class ConanService(object):
             {filename: md5}
         """
         self._authorizer.check_read_conan(self._auth_user, reference)
-        snap = self._file_manager.get_conanfile_snapshot(reference)
+        snap = self._server_store.get_conanfile_snapshot(reference)
         if not snap:
             raise NotFoundException("conanfile not found")
         return snap
@@ -116,7 +162,7 @@ class ConanService(object):
             {filename: url}
         """
         self._authorizer.check_read_conan(self._auth_user, reference)
-        urls = self._file_manager.get_download_conanfile_urls(reference,
+        urls = self._server_store.get_download_conanfile_urls(reference,
                                                               files_subset,
                                                               self._auth_user)
         if not urls:
@@ -126,14 +172,14 @@ class ConanService(object):
     def get_conanfile_upload_urls(self, reference, filesizes):
         _validate_conan_reg_filenames(list(filesizes.keys()))
         self._authorizer.check_write_conan(self._auth_user, reference)
-        urls = self._file_manager.get_upload_conanfile_urls(reference,
+        urls = self._server_store.get_upload_conanfile_urls(reference,
                                                             filesizes,
                                                             self._auth_user)
         return urls
 
     def remove_conanfile(self, reference):
         self._authorizer.check_delete_conan(self._auth_user, reference)
-        self._file_manager.remove_conanfile(reference)
+        self._server_store.remove_conanfile(reference)
 
     def remove_packages(self, reference, package_ids_filter):
         for package_id in package_ids_filter:
@@ -142,15 +188,11 @@ class ConanService(object):
         if not package_ids_filter:  # Remove all packages, check that we can remove conanfile
             self._authorizer.check_delete_conan(self._auth_user, reference)
 
-        self._file_manager.remove_packages(reference, package_ids_filter)
+        self._server_store.remove_packages(reference, package_ids_filter)
 
     def remove_conanfile_files(self, reference, files):
         self._authorizer.check_delete_conan(self._auth_user, reference)
-        self._file_manager.remove_conanfile_files(reference, files)
-
-    def remove_package_files(self, package_reference, files):
-        self._authorizer.check_delete_package(self._auth_user, package_reference)
-        self._file_manager.remove_package_files(package_reference, files)
+        self._server_store.remove_conanfile_files(reference, files)
 
     # Package methods
     def get_package_snapshot(self, package_reference):
@@ -158,7 +200,7 @@ class ConanService(object):
             [filename: {'url': url, 'md5': md5}]
         """
         self._authorizer.check_read_package(self._auth_user, package_reference)
-        snap = self._file_manager.get_package_snapshot(package_reference)
+        snap = self._server_store.get_package_snapshot(package_reference)
         return snap
 
     def get_package_download_urls(self, package_reference, files_subset=None):
@@ -166,7 +208,7 @@ class ConanService(object):
             [filename: {'url': url, 'md5': md5}]
         """
         self._authorizer.check_read_package(self._auth_user, package_reference)
-        urls = self._file_manager.get_download_package_urls(package_reference,
+        urls = self._server_store.get_download_package_urls(package_reference,
                                                             files_subset=files_subset)
         return urls
 
@@ -176,12 +218,12 @@ class ConanService(object):
         :param filesizes: {filepath: bytes}
         :return {filepath: url} """
         try:
-            self._file_manager.get_conanfile_snapshot(package_reference.conan)
+            self._server_store.get_conanfile_snapshot(package_reference.conan)
         except NotFoundException:
             raise NotFoundException("There are no remote conanfiles like %s"
                                     % str(package_reference.conan))
         self._authorizer.check_write_package(self._auth_user, package_reference)
-        urls = self._file_manager.get_upload_package_urls(package_reference,
+        urls = self._server_store.get_upload_package_urls(package_reference,
                                                           filesizes, self._auth_user)
         return urls
 
