@@ -166,13 +166,20 @@ class ConanLib(ConanFile):
         self.assertTrue(error)
         self.assertIn("Getting sources from url: '%s'" % path.replace("\\", "/"), self.client.out)
 
-    def test_excluded_repo_fies(self):
+    def test_excluded_repo_files(self):
         conanfile = base.format(url="auto", revision="auto")
         conanfile = conanfile.replace("short_paths = True", "short_paths = False")
         path, commit = create_local_git_repo({"myfile": "contents",
                                               "ignored.pyc": "bin",
-                                              ".gitignore": "*.pyc\n",
+                                              ".gitignore": """
+*.pyc
+my_excluded_folder
+other_folder/excluded_subfolder
+""",
                                               "myfile.txt": "My file!",
+                                              "my_excluded_folder/some_file": "hey Apple!",
+                                              "other_folder/excluded_subfolder/some_file": "hey Apple!",
+                                              "other_folder/valid_file": "!",
                                               "conanfile.py": conanfile}, branch="my_release")
         self.client.current_folder = path
         self._commit_contents()
@@ -184,8 +191,11 @@ class ConanLib(ConanFile):
         bf = self.client.client_cache.build(pref)
         self.assertTrue(os.path.exists(os.path.join(bf, "myfile.txt")))
         self.assertTrue(os.path.exists(os.path.join(bf, "myfile")))
-        self.assertFalse(os.path.exists(os.path.join(bf, ".git")))
+        self.assertTrue(os.path.exists(os.path.join(bf, ".git")))
         self.assertFalse(os.path.exists(os.path.join(bf, "ignored.pyc")))
+        self.assertFalse(os.path.exists(os.path.join(bf, "my_excluded_folder")))
+        self.assertTrue(os.path.exists(os.path.join(bf, "other_folder", "valid_file")))
+        self.assertFalse(os.path.exists(os.path.join(bf, "other_folder", "excluded_subfolder")))
 
     def test_local_source(self):
         curdir = self.client.current_folder
