@@ -8,6 +8,14 @@ from conans.client.tools.files import replace_in_file
 
 class ConanAliasTest(unittest.TestCase):
 
+    def test_alias_different_name(self):
+        client = TestClient()
+        error = client.run("alias myalias/1.0@user/channel lib/1.0@user/channel",
+                           ignore_error=True)
+        self.assertTrue(error)
+        self.assertIn("An alias can only be defined to a package with the same name",
+                      client.out)
+
     def complete_large_test(self):
         # https://github.com/conan-io/conan/issues/2583
         conanfile0 = """from conans import ConanFile
